@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 ## Copyright (C) 2007, 2008, 2009, 2010, 2012, 2013 Red Hat, Inc.
 ## Copyright (C) 2008 Novell, Inc.
@@ -20,8 +20,6 @@
 
 import cups
 import os
-
-import config
 from debug import *
 import debug
 
@@ -116,7 +114,7 @@ class Connection(SemanticOperations):
         self._destroyed = False
 
         # Decide whether to use direct IPP or PolicyKit.
-        if host == None:
+        if host is None:
             host = cups.getServer()
         use_pk = ((host.startswith ('/') or host == 'localhost') and
                   os.getuid () != 0)
@@ -256,11 +254,11 @@ if __name__ == "__main__":
                                    error_handler=self.getDevices_error)
 
         def getDevices_reply (self, conn, result):
-            print conn, result
+            print (conn, result)
             self.destroy ()
 
         def getDevices_error (self, conn, exc):
-            print repr (exc)
+            print (repr (exc))
             self.destroy ()
 
     t = Test (False)
